@@ -115,73 +115,73 @@
         <translation>Global Actions Manager</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="24"/>
+        <location filename="../main_window.ui" line="27"/>
         <source>Search</source>
-        <translation type="unfinished"></translation>
+        <translation>Search</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="69"/>
+        <location filename="../main_window.ui" line="72"/>
         <source>Add ...</source>
         <translation>Add ...</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="79"/>
+        <location filename="../main_window.ui" line="82"/>
         <source>Remove</source>
         <translation>Remove</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="89"/>
+        <location filename="../main_window.ui" line="92"/>
         <source>Modify ...</source>
         <translation>Modify ...</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="106"/>
+        <location filename="../main_window.ui" line="109"/>
         <source>Swap</source>
         <translation>Swap</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="132"/>
+        <location filename="../main_window.ui" line="135"/>
         <source>Multiple actions behaviour:</source>
         <translation>Multiple actions behaviour:</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="140"/>
+        <location filename="../main_window.ui" line="143"/>
         <source>First</source>
         <comment>globalkeys/config/multipleActions</comment>
-        <translation type="unfinished">First</translation>
+        <translation>First</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="145"/>
+        <location filename="../main_window.ui" line="148"/>
         <source>Last</source>
         <comment>globalkeys/config/multipleActions</comment>
-        <translation type="unfinished">Last</translation>
+        <translation>Last</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="150"/>
+        <location filename="../main_window.ui" line="153"/>
         <source>None</source>
         <comment>globalkeys/config/multipleActions</comment>
-        <translation type="unfinished">None</translation>
+        <translation>None</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="155"/>
+        <location filename="../main_window.ui" line="158"/>
         <source>All</source>
         <comment>globalkeys/config/multipleActions</comment>
-        <translation type="unfinished">All</translation>
+        <translation>All</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="180"/>
+        <location filename="../main_window.ui" line="183"/>
         <source>Default</source>
-        <translation type="unfinished"></translation>
+        <translation>Default</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="200"/>
+        <location filename="../main_window.ui" line="203"/>
         <source>Close</source>
         <translation>Close</translation>
     </message>
     <message>
         <location filename="../main_window.cpp" line="191"/>
         <source>Restore Default</source>
-        <translation type="unfinished"></translation>
+        <translation>Restore Default</translation>
     </message>
     <message>
         <location filename="../main_window.cpp" line="192"/>
