@@ -6,7 +6,7 @@
     <message>
         <location filename="../default_model.cpp" line="51"/>
         <source>Command</source>
-        <translation type="unfinished">Komandoa</translation>
+        <translation>Komandoa</translation>
     </message>
     <message>
         <location filename="../default_model.cpp" line="52"/>
@@ -26,12 +26,12 @@
     <message>
         <location filename="../default_model.cpp" line="146"/>
         <source>Shortcut</source>
-        <translation type="unfinished">Lasterbidea</translation>
+        <translation>Lasterbidea</translation>
     </message>
     <message>
         <location filename="../default_model.cpp" line="149"/>
         <source>Description</source>
-        <translation type="unfinished">Deskribapena</translation>
+        <translation>Deskribapena</translation>
     </message>
     <message>
         <location filename="../default_model.cpp" line="152"/>
@@ -99,12 +99,12 @@
     <message>
         <location filename="../edit_action_dialog.ui" line="232"/>
         <source>&amp;Interface:</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Interfazea</translation>
     </message>
     <message>
         <location filename="../edit_action_dialog.ui" line="245"/>
         <source>&amp;Method:</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Metodoa:</translation>
     </message>
 </context>
 <context>
@@ -115,68 +115,68 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="24"/>
+        <location filename="../main_window.ui" line="27"/>
         <source>Search</source>
-        <translation type="unfinished"></translation>
+        <translation>Bilatu</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="69"/>
+        <location filename="../main_window.ui" line="72"/>
         <source>Add ...</source>
-        <translation type="unfinished"></translation>
+        <translation>Gehitu ...</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="79"/>
+        <location filename="../main_window.ui" line="82"/>
         <source>Remove</source>
-        <translation type="unfinished">Kendu</translation>
+        <translation>Kendu</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="89"/>
+        <location filename="../main_window.ui" line="92"/>
         <source>Modify ...</source>
-        <translation type="unfinished"></translation>
+        <translation>Aldatu ...</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="106"/>
+        <location filename="../main_window.ui" line="109"/>
         <source>Swap</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="132"/>
+        <location filename="../main_window.ui" line="135"/>
         <source>Multiple actions behaviour:</source>
-        <translation type="unfinished"></translation>
+        <translation>Hainbat ekintza portaera:</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="140"/>
+        <location filename="../main_window.ui" line="143"/>
         <source>First</source>
         <comment>globalkeys/config/multipleActions</comment>
-        <translation type="unfinished"></translation>
+        <translation>Lehenengoa</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="145"/>
+        <location filename="../main_window.ui" line="148"/>
         <source>Last</source>
         <comment>globalkeys/config/multipleActions</comment>
-        <translation type="unfinished"></translation>
+        <translation>Azkena</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="150"/>
+        <location filename="../main_window.ui" line="153"/>
         <source>None</source>
         <comment>globalkeys/config/multipleActions</comment>
-        <translation type="unfinished">Bat ere ez</translation>
+        <translation>Bat ere ez</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="155"/>
+        <location filename="../main_window.ui" line="158"/>
         <source>All</source>
         <comment>globalkeys/config/multipleActions</comment>
-        <translation type="unfinished"></translation>
+        <translation>Denak</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="180"/>
+        <location filename="../main_window.ui" line="183"/>
         <source>Default</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="200"/>
+        <location filename="../main_window.ui" line="203"/>
         <source>Close</source>
-        <translation type="unfinished">Itxi</translation>
+        <translation>Itxi</translation>
     </message>
     <message>
         <location filename="../main_window.cpp" line="191"/>
@@ -187,7 +187,8 @@
         <location filename="../main_window.cpp" line="192"/>
         <source>Your defined shortcuts will be removed.
 Do you want to proceed?</source>
-        <translation type="unfinished"></translation>
+        <translation>Definitutako lasterbideak kenduko dira.
+Jarraitu nahi duzu?</translation>
     </message>
 </context>
 </TS>
